@@ -43,24 +43,17 @@ def support_submit_legacy_api(func):
         # Raise an exception or warn based on the detected API version.
         if api_version is None:
             raise RuntimeError("Unable to determine legacy API use.")
-        elif api_version < 3:
+        elif api_version < 5:
             raise RuntimeError(
                 "This FlowProject implementation uses deprecated API "
-                "version 0.{}.x Please downgrade your signac-flow installation "
+                "version 0.{}.x. Please downgrade your signac-flow installation "
                 "or update your project.".format(api_version))
         else:
             logger.warning(
                 "Activating legacy layer for API version 0.{}.x.".format(api_version))
 
         # Delegate to legacy submit function based on detected API version.
-        if api_version == 4:
-            kwargs.setdefault('walltime', 12)
-            if kwargs.get('nn') is not None:
-                raise RuntimeError(
-                    "You can't directly provide the number of nodes with the legacy API "
-                    "for version 0.4.x!")
-            return submit_04(self=self, env=env, *args, **kwargs)
-        elif api_version == 5:
+        if api_version == 5:
             if 'serial' in kwargs and 'parallel' not in kwargs:
                 kwargs['parallel'] = not kwargs.pop('serial')
             return func(self, env=env, _api_version=5, *args, **kwargs)
@@ -72,82 +65,85 @@ def support_submit_legacy_api(func):
 
 def submit_04(self, env, job_ids=None, operation_name=None, walltime=None,
               num=None, force=False, bundle_size=1, cmd=None, requires=None, **kwargs):
-        """Submit job-operations to the scheduler.
+    """Submit job-operations to the scheduler.
 
-        This method will submit an operation for each job to the environment's scheduler,
-        unless the job is considered active, e.g., because an operation associated with
-        the same job has alreay been submitted.
+    This method will submit an operation for each job to the environment's scheduler,
+    unless the job is considered active, e.g., because an operation associated with
+    the same job has alreay been submitted.
 
-        The actual execution of operations is controlled in the :py:meth:`~.submit_user`
-        method which must be implemented by the user.
+    The actual execution of operations is controlled in the :py:meth:`~.submit_user`
+    method which must be implemented by the user.
 
-        :param env: The env instance.
-        :type env: :class:`~.flow.manage.ComputeEnvironment`
-        :param job_ids: A list of job_id's, whose next operation shall be executed.
-            Defaults to all jobs found in the workspace.
-        :param operation_name: If not None, only execute operations with this name.
-        :param walltime: The maximum wallclock time in hours.
-        :type walltime: float
-        :param num: If not None, limit number of submitted operations to `num`.
-        :type num: int
-        :param force: Ignore warnings and checks during submission, just submit.
-        :type force: bool
-        :param bundle_size: Bundle up to 'bundle_size' number of operations during submission.
-        :type bundle_size: int
-        :param cmd: Construct and submit an operation "on-the-fly" instead of submitting
-            the "next operation".
-        :type cmd: str
-        :param requires: A job's set of classification labels must fully intersect with
-            the labels provided as part of this argument to be considered for submission.
-        :type requires: Iterable of str
-        :param kwargs: Other keyword arguments which are forwarded to down-stream methods.
-        """
-        from .project import JobOperation, make_bundles
-        from itertools import islice
-        import datetime
-        if walltime is not None:
-            walltime = datetime.timedelta(hours=walltime)
+    :param env: The env instance.
+    :type env: :class:`~.flow.manage.ComputeEnvironment`
+    :param job_ids: A list of job_id's, whose next operation shall be executed.
+        Defaults to all jobs found in the workspace.
+    :param operation_name: If not None, only execute operations with this name.
+    :param walltime: The maximum wallclock time in hours.
+    :type walltime: float
+    :param num: If not None, limit number of submitted operations to `num`.
+    :type num: int
+    :param force: Ignore warnings and checks during submission, just submit.
+    :type force: bool
+    :param bundle_size: Bundle up to 'bundle_size' number of operations during submission.
+    :type bundle_size: int
+    :param cmd: Construct and submit an operation "on-the-fly" instead of submitting
+        the "next operation".
+    :type cmd: str
+    :param requires: A job's set of classification labels must fully intersect with
+        the labels provided as part of this argument to be considered for submission.
+    :type requires: Iterable of str
+    :param kwargs: Other keyword arguments which are forwarded to down-stream methods.
+    """
+    from .project import JobOperation, make_bundles
+    from itertools import islice
+    import datetime
+    if walltime is not None:
+        walltime = datetime.timedelta(hours=walltime)
 
-        if job_ids:
-            jobs = (self.open_job(id=_id) for _id in job_ids)
+    if job_ids:
+        jobs = (self.open_job(id=_id) for _id in job_ids)
+    else:
+        jobs = iter(self)
+
+    def get_op(job):
+        if cmd is None:
+            return self.next_operation(job)
         else:
-            jobs = iter(self)
+            return JobOperation(name='user-cmd', cmd=cmd.format(job=job), job=job)
 
-        def get_op(job):
-            if cmd is None:
-                return self.next_operation(job)
-            else:
-                return JobOperation(name='user-cmd', cmd=cmd.format(job=job), job=job)
+    def eligible(op):
+        if force:
+            return True
+        if (
+            cmd is None
+            and operation_name is not None
+            and op.name != operation_name
+        ):
+            return False
+        if requires is not None:
+            labels = set(self.classify(op.job))
+            if not all([req in labels for req in requires]):
+                return False
+        return self.eligible_for_submission(op)
 
-        def eligible(op):
-            if force:
-                return True
-            if cmd is None:
-                if operation_name is not None and op.name != operation_name:
-                    return False
-            if requires is not None:
-                labels = set(self.classify(op.job))
-                if not all([req in labels for req in requires]):
-                    return False
-            return self.eligible_for_submission(op)
+    # Get the first num eligible operations
+    operations = islice((op for op in map(get_op, jobs) if eligible(op)), num)
 
-        # Get the first num eligible operations
-        operations = islice((op for op in map(get_op, jobs) if eligible(op)), num)
-
-        # Bundle all eligible operations and submit the bundles
-        for bundle in make_bundles(operations, bundle_size):
-            _id = self._store_bundled(bundle)
-            status = self.submit_user(
-                env=env,
-                _id=_id,
-                operations=bundle,
-                walltime=walltime,
-                force=force,
-                **kwargs)
-            if status is not None:
-                logger.info("Submitted job '{}' ({}).".format(_id, status.name))
-                for op in bundle:
-                    op.set_status(status)
+    # Bundle all eligible operations and submit the bundles
+    for bundle in make_bundles(operations, bundle_size):
+        _id = self._store_bundled(bundle)
+        status = self.submit_user(
+            env=env,
+            _id=_id,
+            operations=bundle,
+            walltime=walltime,
+            force=force,
+            **kwargs)
+        if status is not None:
+            logger.info("Submitted job '{}' ({}).".format(_id, status.name))
+            for op in bundle:
+                op.set_status(status)
 
 
 def support_submit_operations_legacy_api(func):
@@ -199,6 +195,42 @@ def support_run_legacy_api(func):
     return wrapper
 
 
+def support_print_status_legacy_api(func):
+    from .scheduling.base import Scheduler
+
+    @functools.wraps(func)
+    def wrapper(self, jobs=None, *args, **kwargs):
+        if kwargs.pop('full', False):
+            kwargs['detailed'] = kwargs['all_ops'] = True
+
+        # remove parser args
+        for arg in ('func', 'verbose', 'debug', 'show_traceback', 'job_id', 'filter', 'doc_filter'):
+            if arg in kwargs:
+                del kwargs[arg]
+
+        for deprecated_arg in ('scheduler', 'pool'):
+            if deprecated_arg in kwargs:
+                value = kwargs.pop(deprecated_arg)
+                if value is None:
+                    warnings.warn(
+                        "The {} argument for flow.FlowProject.print_status() "
+                        " was deprecated as of signac-flow version 0.6 and has "
+                        "been removed as of version 0.7!".format(deprecated_arg),
+                        DeprecationWarning)
+                else:
+                    raise RuntimeError(
+                        "The {} argument for flow.FlowProject.print_status() "
+                        " was deprecated as of signac-flow version 0.6 and has "
+                        "been removed as of version 0.7!".format(deprecated_arg))
+        if isinstance(jobs, Scheduler):
+            raise ValueError(
+                "The first argument of flow.FlowProject.print_status() is 'jobs' "
+                "as of signac-flow version 0.6!")
+
+        return func(self, jobs=jobs, *args, **kwargs)
+    return wrapper
+
+
 class JobsCursorWrapper(object):
     """Enables the execution of workflows on dynamic data spaces.
 
